? placeholder-at-is_array.benchmark.txt
? placeholder-at.benchmark.txt
? placeholder-db_placeholders.benchmark.txt
? placeholer-is_array.benchmark.txt
? modules/simpletest/tests/343502.test
Index: modules/comment/comment.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/comment/comment.module,v
retrieving revision 1.670
diff -u -p -r1.670 comment.module
--- modules/comment/comment.module	9 Dec 2008 11:30:24 -0000	1.670
+++ modules/comment/comment.module	11 Dec 2008 01:33:17 -0000
@@ -2010,9 +2010,9 @@ function vancode2int($c = '00') {
 }
 
 /**
- * Implementation of hook_hook_info().
+ * Implementation of hook_trigger_info().
  */
-function comment_hook_info() {
+function comment_trigger_info() {
   return array(
     'comment' => array(
       'comment' => array(
Index: modules/node/node.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/node/node.module,v
retrieving revision 1.1001
diff -u -p -r1.1001 node.module
--- modules/node/node.module	5 Dec 2008 22:18:45 -0000	1.1001
+++ modules/node/node.module	11 Dec 2008 01:33:19 -0000
@@ -2685,9 +2685,9 @@ function theme_node_submitted($node) {
 }
 
 /**
- * Implementation of hook_hook_info().
+ * Implementation of hook_trigger_info().
  */
-function node_hook_info() {
+function node_trigger_info() {
   return array(
     'node' => array(
       'nodeapi' => array(
Index: modules/system/system.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/system.module,v
retrieving revision 1.650
diff -u -p -r1.650 system.module
--- modules/system/system.module	28 Nov 2008 09:25:59 -0000	1.650
+++ modules/system/system.module	11 Dec 2008 01:33:22 -0000
@@ -1528,9 +1528,9 @@ function system_cron() {
 }
 
 /**
- * Implementation of hook_hook_info().
+ * Implementation of hook_trigger_info().
  */
-function system_hook_info() {
+function system_trigger_info() {
   return array(
     'system' => array(
       'cron' => array(
Index: modules/taxonomy/taxonomy.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/taxonomy/taxonomy.module,v
retrieving revision 1.447
diff -u -p -r1.447 taxonomy.module
--- modules/taxonomy/taxonomy.module	9 Dec 2008 11:30:25 -0000	1.447
+++ modules/taxonomy/taxonomy.module	11 Dec 2008 01:33:24 -0000
@@ -1534,9 +1534,9 @@ function taxonomy_implode_tags($tags, $v
 }
 
 /**
- * Implementation of hook_hook_info().
+ * Implementation of hook_trigger_info().
  */
-function taxonomy_hook_info() {
+function taxonomy_trigger_info() {
   return array(
     'taxonomy' => array(
       'taxonomy' => array(
Index: modules/trigger/trigger.admin.inc
===================================================================
RCS file: /cvs/drupal/drupal/modules/trigger/trigger.admin.inc,v
retrieving revision 1.7
diff -u -p -r1.7 trigger.admin.inc
--- modules/trigger/trigger.admin.inc	16 Jul 2008 21:59:28 -0000	1.7
+++ modules/trigger/trigger.admin.inc	11 Dec 2008 01:33:24 -0000
@@ -25,10 +25,10 @@ function trigger_assign($type = NULL) {
   }
 
   $output = '';
-  $hooks = module_invoke_all('hook_info');
-  foreach ($hooks as $module => $hook) {
-    if (isset($hook[$type])) {
-      foreach ($hook[$type] as $op => $description) {
+  $triggers = module_invoke_all('trigger_info');
+  foreach ($triggers as $module => $trigger) {
+    if (isset($trigger[$type])) {
+      foreach ($trigger[$type] as $op => $description) {
         $form_id = 'trigger_' . $type . '_' . $op . '_assign_form';
         $output .= drupal_get_form($form_id, $type, $op, $description['runs when']);
       }
Index: modules/trigger/trigger.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/trigger/trigger.module,v
retrieving revision 1.23
diff -u -p -r1.23 trigger.module
--- modules/trigger/trigger.module	9 Dec 2008 11:30:25 -0000	1.23
+++ modules/trigger/trigger.module	11 Dec 2008 01:33:25 -0000
@@ -86,8 +86,8 @@ function trigger_menu() {
 
   // We want contributed modules to be able to describe
   // their hooks and have actions assignable to them.
-  $hooks = module_invoke_all('hook_info');
-  foreach ($hooks as $module => $hook) {
+  $triggers = module_invoke_all('trigger_info');
+  foreach ($triggers as $module => $trigger) {
     // We've already done these.
     if (in_array($module, array('node', 'comment', 'user', 'system', 'taxonomy'))) {
       continue;
@@ -159,11 +159,11 @@ function trigger_theme() {
  * same assignment form definition for each node-op combination.
  */
 function trigger_forms() {
-  $hooks = module_invoke_all('hook_info');
-  foreach ($hooks as $module => $info) {
-    foreach ($hooks[$module] as $hook => $ops) {
+  $trigger = module_invoke_all('trigger_info');
+  foreach ($triggers as $module => $info) {
+    foreach ($triggers[$module] as $trigger => $ops) {
       foreach ($ops as $op => $description) {
-        $forms['trigger_' . $hook . '_' . $op . '_assign_form'] = array('callback' => 'trigger_assign_form');
+        $forms['trigger_' . $trigger . '_' . $op . '_assign_form'] = array('callback' => 'trigger_assign_form');
       }
     }
   }
Index: modules/user/user.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user.module,v
retrieving revision 1.944
diff -u -p -r1.944 user.module
--- modules/user/user.module	29 Nov 2008 09:33:51 -0000	1.944
+++ modules/user/user.module	11 Dec 2008 01:33:27 -0000
@@ -2172,9 +2172,9 @@ function _user_password_dynamic_validati
 }
 
 /**
- * Implementation of hook_hook_info().
+ * Implementation of hook_trigger_info().
  */
-function user_hook_info() {
+function user_trigger_info() {
   return array(
     'user' => array(
       'user' => array(

Index: modules/trigger/trigger.api.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/trigger/trigger.api.php,v
retrieving revision 1.1
diff -u -p -r1.1 trigger.api.php
--- modules/trigger/trigger.api.php	25 Nov 2008 02:37:33 -0000	1.1
+++ modules/trigger/trigger.api.php	11 Dec 2008 01:33:25 -0000
@@ -47,7 +47,7 @@
  *       modules and you simply want to declare support for all possible hooks,
  *       you can set 'hooks' => array('any' => TRUE).  Common hooks are 'user',
  *       'nodeapi', 'comment', or 'taxonomy'. Any hook that has been described
  *       to Drupal in hook_hook_info() will work is a possiblity.
  *     - 'behavior': (optional) Human-readable array of behavior descriptions.
  *       The only one we have now is 'changes node property'.  You will almost
  *       certainly never have to return this in your own implementations of this
@@ -121,13 +121,13 @@ function hook_action_info_alter(&$action
  *         - Each of those arrays have a key of 'runs when' and a value which is
  *           an English description of the hook.
  *
  * For example, the node_hook_info implementation has 'node' as the outermost
  * key, as that's the module it's in.  Next it has 'nodeapi' as the next key,
  * as hook_nodeapi() is what applies to changes in nodes.  Finally the keys
  * after that are the various operations for hook_nodeapi() that the node module
  * is exposing as triggers.
  */
-function hook_hook_info() {
+function hook_trigger_info() {
   return array(
     'node' => array(
       'nodeapi' => array(
@@ -47,7 +47,7 @@
  *       you can set 'hooks' => array('any' => TRUE).  Common hooks are 'user',
  *       'nodeapi', 'comment', or 'taxonomy'. Any hook that has been described
- *       to Drupal in hook_hook_info() will work is a possiblity.
+ *       to Drupal in hook_trigger_info() will work is a possibility.
  *     - 'behavior': (optional) Human-readable array of behavior descriptions.
  *       The only one we have now is 'changes node property'.  You will almost
@@ -121,13 +121,13 @@ function hook_action_info_alter(&$action
  *           an English description of the hook.
  *
- * For example, the node_hook_info implementation has 'node' as the outermost
+ * For example, the node_trigger_info implementation has 'node' as the outermost
  * key, as that's the module it's in.  Next it has 'nodeapi' as the next key,
  * as hook_nodeapi() is what applies to changes in nodes.  Finally the keys